import { GoogleAuth, GoogleAuthOptions } from 'google-auth-library';
interface AuthOptions extends GoogleAuthOptions {
    /**
     * The host name used to access the compute API.
     * Defaults to `compute.googleapis.com`.
     */
    apiEndpoint?: string;
}
export declare type GCEImagesConfig = Omit<AuthOptions, 'authClient'> & {
    authClient?: GoogleAuth;
};
export interface GetOptions {
    deprecated?: boolean;
    osNames?: string[];
}
export interface Image {
    creationTimestamp: string;
    deprecated: {
        state: 'ACTIVE' | 'DEPRECATED' | 'OBSOLETE' | 'DELETED';
        replacement: string;
        deprecated: string;
        obsolete: string;
        deleted: string;
    };
    kind: 'compute#image';
    selfLink: string;
    id: string;
    name: string;
    description: string;
    sourceType: string;
    rawDisk: {
        source: string;
        containerType: string;
    };
    status: string;
    archiveSizeBytes: number;
    diskSizeGb: number;
    licenses: string[];
    family: string;
    labelFingerprint: string;
    guestOsFeatures: {
        type: 'MULTI_IP_SUBNET' | 'UEFI_COMPATIBLE' | 'VIRTIO_SCSI_MULTIQUEUE' | 'WINDOWS';
    }[];
    licenseCodes: string[];
    storageLocations: string[];
}
export interface GetAllCallback {
    (err: Error | null, images?: Image[] | ImagesMap): void;
}
export interface GetLatestCallback {
    (err: Error | null, images?: Image | ImageMap): void;
}
export interface ImagesMap {
    [index: string]: Image[];
}
export interface ImageMap {
    [index: string]: Image;
}
interface ParsedArguments<O, C> {
    options: O;
    callback: C;
}
export interface OSUrls {
    centos: string;
    'container-vm': string;
    coreos: string;
    debian: string;
    redhat: string;
    opensuse: string;
    suse: string;
    ubuntu: string;
    windows: string;
}
export declare class GCEImages {
    private _auth;
    private apiEndpoint;
    OS_URLS: OSUrls;
    OS_TO_URL: {
        [index: string]: string;
    };
    constructor(config?: GCEImagesConfig | AuthOptions);
    getProjectId(): Promise<string>;
    /**
     * Get all available images.
     *
     * @param {string=|object=} options - If a string, treat as an OS to fetch images for.
     * @param {boolean} options.deprecated [false] - Include deprecated results.
     * @param {array} options.osNames [all] - OS names to include in the results.
     * @param {function} callback - Callback function.
     * @returns {Promise} if callback is omitted.
     */
    getAll(cb: GetAllCallback): void;
    getAll(opts?: GetOptions | string): Promise<Image[] | ImagesMap>;
    getAll(opts: GetOptions | string, cb: GetAllCallback): void;
    private getAllAsync;
    /**
     * Get all available images, but only return the newest one.
     *
     * @param {string=|object=} options - If a string, treat as an OS to fetch
     *                                    images for.
     * @param {boolean} options.deprecated [false] - Include deprecated results.
     * @param {array} options.osNames [all] - OS names to include in the results.
     * @param {function} callback - Callback function.
     * @returns {Promise} if callback is omitted.
     */
    getLatest(cb: GetLatestCallback): void;
    getLatest(opts?: GetOptions | string): Promise<Image | ImageMap>;
    getLatest(opts: GetOptions | string, cb: GetLatestCallback): void;
    private getLatestAsync;
    _getAllByOS(options: GetOptions & {
        osNames: string[];
    }): Promise<Image[]>;
    _parseArguments<O, C>(options: any, callback: any): ParsedArguments<O, C>;
    _parseOsInput(os: string): {
        name: string;
        version: string;
        url: string;
    };
    _filterDeprecated(image: Image): boolean;
    _sortNewestFirst(imageA: Image, imageB: Image): 1 | -1 | 0;
}
export {};
